# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.schemas.v1 import schemas_v1_pb2 as strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2


class SchemasServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSchemas = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ListSchemas',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.FromString,
                )
        self.GetSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.FromString,
                )
        self.CreateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/CreateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.FromString,
                )
        self.UpdateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/UpdateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.FromString,
                )
        self.GetSchemaCode = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaCode',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.FromString,
                )
        self.ActivateSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ActivateSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.FromString,
                )
        self.DeleteSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/DeleteSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.FromString,
                )
        self.ArchiveSchema = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/ArchiveSchema',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.FromString,
                )
        self.GetSchemaDefinition = channel.unary_unary(
                '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaDefinition',
                request_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.FromString,
                )


class SchemasServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSchemas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchemaCode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ArchiveSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSchemaDefinition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SchemasServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSchemas': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSchemas,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.SerializeToString,
            ),
            'GetSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.SerializeToString,
            ),
            'CreateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.SerializeToString,
            ),
            'UpdateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.SerializeToString,
            ),
            'GetSchemaCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchemaCode,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.SerializeToString,
            ),
            'ActivateSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.SerializeToString,
            ),
            'DeleteSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.SerializeToString,
            ),
            'ArchiveSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.ArchiveSchema,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.SerializeToString,
            ),
            'GetSchemaDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSchemaDefinition,
                    request_deserializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.schemas.v1.SchemasService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SchemasService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSchemas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ListSchemas',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ListSchemasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/CreateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.CreateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/UpdateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.UpdateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchemaCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaCode',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaCodeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ActivateSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ActivateSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ActivateSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/DeleteSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.DeleteSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ArchiveSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/ArchiveSchema',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.ArchiveSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSchemaDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.schemas.v1.SchemasService/GetSchemaDefinition',
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionRequest.SerializeToString,
            strmprivacy_dot_api_dot_schemas_dot_v1_dot_schemas__v1__pb2.GetSchemaDefinitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/handles/v1/handles_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/handles/v1/handles_v1.proto\x12\x1astrmprivacy.api.handles.v1\x1a\x17validate/validate.proto\"S\n\x1eListInstallationHandlesRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"T\n\x1fListInstallationHandlesResponse\x12\x31\n\x14installation_handles\x18\x01 \x03(\tR\x13installationHandles2\xa5\x01\n\x0eHandlesService\x12\x92\x01\n\x17ListInstallationHandles\x12:.strmprivacy.api.handles.v1.ListInstallationHandlesRequest\x1a;.strmprivacy.api.handles.v1.ListInstallationHandlesResponseBf\n\x1dio.strmprivacy.api.handles.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handlesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.handles.v1.handles_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.handles.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/handles/v1;handles'
  _LISTINSTALLATIONHANDLESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLATIONHANDLESREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTINSTALLATIONHANDLESREQUEST._serialized_start=100
  _LISTINSTALLATIONHANDLESREQUEST._serialized_end=183
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_start=185
  _LISTINSTALLATIONHANDLESRESPONSE._serialized_end=269
  _HANDLESSERVICE._serialized_start=272
  _HANDLESSERVICE._serialized_end=437
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.sinks.v1 import sinks_v1_pb2 as strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2


class SinksServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSinks = channel.unary_unary(
                '/strmprivacy.api.sinks.v1.SinksService/ListSinks',
                request_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksResponse.FromString,
                )
        self.GetSink = channel.unary_unary(
                '/strmprivacy.api.sinks.v1.SinksService/GetSink',
                request_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkResponse.FromString,
                )
        self.DeleteSink = channel.unary_unary(
                '/strmprivacy.api.sinks.v1.SinksService/DeleteSink',
                request_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkResponse.FromString,
                )
        self.CreateSink = channel.unary_unary(
                '/strmprivacy.api.sinks.v1.SinksService/CreateSink',
                request_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkResponse.FromString,
                )


class SinksServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSinks(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SinksServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSinks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSinks,
                    request_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksResponse.SerializeToString,
            ),
            'GetSink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSink,
                    request_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkResponse.SerializeToString,
            ),
            'DeleteSink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSink,
                    request_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkResponse.SerializeToString,
            ),
            'CreateSink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSink,
                    request_deserializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.sinks.v1.SinksService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SinksService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.sinks.v1.SinksService/ListSinks',
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksRequest.SerializeToString,
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.ListSinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.sinks.v1.SinksService/GetSink',
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkRequest.SerializeToString,
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.GetSinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.sinks.v1.SinksService/DeleteSink',
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkRequest.SerializeToString,
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.DeleteSinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.sinks.v1.SinksService/CreateSink',
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkRequest.SerializeToString,
            strmprivacy_dot_api_dot_sinks_dot_v1_dot_sinks__v1__pb2.CreateSinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/data_connector_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/agents/v1/data_connector_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"&\n\x1fGetDesiredDataConnectorsRequest:\x03\xf8\x42\x00\"w\n GetDesiredDataConnectorsResponse\x12S\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorR\x0e\x64\x61taConnectors2\xb2\x01\n\x1a\x44\x61taConnectorsAgentService\x12\x93\x01\n\x18GetDesiredDataConnectors\x12:.strmprivacy.api.agents.v1.GetDesiredDataConnectorsRequest\x1a;.strmprivacy.api.agents.v1.GetDesiredDataConnectorsResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.agents.v1.data_connector_agent_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDDATACONNECTORSREQUEST._options = None
  _GETDESIREDDATACONNECTORSREQUEST._serialized_options = b'\370B\000'
  _GETDESIREDDATACONNECTORSREQUEST._serialized_start=158
  _GETDESIREDDATACONNECTORSREQUEST._serialized_end=196
  _GETDESIREDDATACONNECTORSRESPONSE._serialized_start=198
  _GETDESIREDDATACONNECTORSRESPONSE._serialized_end=317
  _DATACONNECTORSAGENTSERVICE._serialized_start=320
  _DATACONNECTORSAGENTSERVICE._serialized_end=498
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
import pathlib
import pkg_resources
from datetime import datetime
from setuptools import setup, find_packages

with pathlib.Path('requirements.txt').open() as requirements_txt:
    install_requires = [
        str(requirement)
        for requirement
        in pkg_resources.parse_requirements(requirements_txt)
    ]

with open('VERSION') as version_file:
    parts = version_file.read().rstrip().split('-')

    if len(parts) > 1:
        # take version without git sha, because that's not allowed due to PEP440
        raw_version = parts[0]
        version = f'{raw_version}-dev{datetime.now().strftime("%Y%m%d%H%M")}'
    else:
        version = parts[0]

setup(
    author="Stream Machine B.V.",
    author_email='apis@strmprivacy.io',
    python_requires='>=3.6',
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
    ],
    description="STRM Privacy API definitions",
    install_requires=install_requires,
    include_package_data=True,
    keywords='strmprivacy api definitions',
    name='strmprivacy-api-definitions',
    packages=find_packages(),
    setup_requires=[],
    version=version,
    zip_safe=False,
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_subjects.v1 import data_subjects_v1_pb2 as strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2


class DataSubjectsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataSubjectKeylinks = channel.unary_unary(
                '/strmprivacy.api.data_subjects.v1.DataSubjectsService/ListDataSubjectKeylinks',
                request_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksResponse.FromString,
                )
        self.AddDataSubjectsKeyLinks = channel.unary_unary(
                '/strmprivacy.api.data_subjects.v1.DataSubjectsService/AddDataSubjectsKeyLinks',
                request_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksResponse.FromString,
                )
        self.DeleteDataSubjects = channel.unary_unary(
                '/strmprivacy.api.data_subjects.v1.DataSubjectsService/DeleteDataSubjects',
                request_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsResponse.FromString,
                )
        self.ListDataSubjects = channel.unary_unary(
                '/strmprivacy.api.data_subjects.v1.DataSubjectsService/ListDataSubjects',
                request_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsResponse.FromString,
                )


class DataSubjectsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataSubjectKeylinks(self, request, context):
        """
        Retrieve all key links associated with certain data subject(s)

        returns: a list of data subject with their associated key links and their
        expiry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDataSubjectsKeyLinks(self, request, context):
        """called by an entity that can create key link(s) like the event-gateway or a batch-job

        typically (but not necessarily) only one key link is added at the same time.

        The list of DatasubjectKeylinks is combined with a project_id; the DSS uses this to find the linked
        organization_id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataSubjects(self, request, context):
        """
        delete data subjects from the DSS database, and returns the deleted key links and timestamps
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDataSubjects(self, request, context):
        """
        list data subjects from the DSS database
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSubjectsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataSubjectKeylinks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataSubjectKeylinks,
                    request_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksResponse.SerializeToString,
            ),
            'AddDataSubjectsKeyLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDataSubjectsKeyLinks,
                    request_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksResponse.SerializeToString,
            ),
            'DeleteDataSubjects': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataSubjects,
                    request_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsResponse.SerializeToString,
            ),
            'ListDataSubjects': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataSubjects,
                    request_deserializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_subjects.v1.DataSubjectsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSubjectsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataSubjectKeylinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_subjects.v1.DataSubjectsService/ListDataSubjectKeylinks',
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectKeylinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddDataSubjectsKeyLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_subjects.v1.DataSubjectsService/AddDataSubjectsKeyLinks',
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.AddDataSubjectsKeyLinksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataSubjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_subjects.v1.DataSubjectsService/DeleteDataSubjects',
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.DeleteDataSubjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDataSubjects(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_subjects.v1.DataSubjectsService/ListDataSubjects',
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__subjects_dot_v1_dot_data__subjects__v1__pb2.ListDataSubjectsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.streams.v1 import streams_v1_pb2 as strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2


class StreamsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListStreams = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/ListStreams',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.FromString,
                )
        self.ListExtendedStreams = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/ListExtendedStreams',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.FromString,
                )
        self.GetStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/GetStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.FromString,
                )
        self.DeleteStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/DeleteStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.FromString,
                )
        self.CreateStream = channel.unary_unary(
                '/strmprivacy.api.streams.v1.StreamsService/CreateStream',
                request_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.FromString,
                )


class StreamsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExtendedStreams(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStreams,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.SerializeToString,
            ),
            'ListExtendedStreams': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExtendedStreams,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.SerializeToString,
            ),
            'GetStream': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.SerializeToString,
            ),
            'DeleteStream': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.SerializeToString,
            ),
            'CreateStream': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStream,
                    request_deserializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.streams.v1.StreamsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StreamsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/ListStreams',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExtendedStreams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/ListExtendedStreams',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.ListExtendedStreamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/GetStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.GetStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/DeleteStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.DeleteStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.streams.v1.StreamsService/CreateStream',
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamRequest.SerializeToString,
            strmprivacy_dot_api_dot_streams_dot_v1_dot_streams__v1__pb2.CreateStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/kafka_exporters/v1/kafka_exporters_v1.proto\x12\"strmprivacy.api.kafka_exporters.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"r\n\x19ListKafkaExportersRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"q\n\x1aListKafkaExportersResponse\x12S\n\x0fkafka_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\x0ekafkaExporters\"\x85\x01\n\x1a\x44\x65leteKafkaExporterRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x1d\n\x1b\x44\x65leteKafkaExporterResponse\"y\n\x1a\x43reateKafkaExporterRequest\x12[\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rkafkaExporter\"p\n\x1b\x43reateKafkaExporterResponse\x12Q\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\rkafkaExporter\"d\n\x17GetKafkaExporterRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"m\n\x18GetKafkaExporterResponse\x12Q\n\x0ekafka_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\rkafkaExporter2\xef\x04\n\x15KafkaExportersService\x12\x93\x01\n\x12ListKafkaExporters\x12=.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersRequest\x1a>.strmprivacy.api.kafka_exporters.v1.ListKafkaExportersResponse\x12\x8d\x01\n\x10GetKafkaExporter\x12;.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterRequest\x1a<.strmprivacy.api.kafka_exporters.v1.GetKafkaExporterResponse\x12\x96\x01\n\x13\x44\x65leteKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.DeleteKafkaExporterResponse\x12\x96\x01\n\x13\x43reateKafkaExporter\x12>.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterRequest\x1a?.strmprivacy.api.kafka_exporters.v1.CreateKafkaExporterResponseB~\n%io.strmprivacy.api.kafka_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exportersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_exporters.v1.kafka_exporters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.kafka_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_exporters/v1;kafka_exporters'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTKAFKAEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._options = None
  _CREATEKAFKAEXPORTERREQUEST.fields_by_name['kafka_exporter']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTKAFKAEXPORTERSREQUEST._serialized_start=171
  _LISTKAFKAEXPORTERSREQUEST._serialized_end=285
  _LISTKAFKAEXPORTERSRESPONSE._serialized_start=287
  _LISTKAFKAEXPORTERSRESPONSE._serialized_end=400
  _DELETEKAFKAEXPORTERREQUEST._serialized_start=403
  _DELETEKAFKAEXPORTERREQUEST._serialized_end=536
  _DELETEKAFKAEXPORTERRESPONSE._serialized_start=538
  _DELETEKAFKAEXPORTERRESPONSE._serialized_end=567
  _CREATEKAFKAEXPORTERREQUEST._serialized_start=569
  _CREATEKAFKAEXPORTERREQUEST._serialized_end=690
  _CREATEKAFKAEXPORTERRESPONSE._serialized_start=692
  _CREATEKAFKAEXPORTERRESPONSE._serialized_end=804
  _GETKAFKAEXPORTERREQUEST._serialized_start=806
  _GETKAFKAEXPORTERREQUEST._serialized_end=906
  _GETKAFKAEXPORTERRESPONSE._serialized_start=908
  _GETKAFKAEXPORTERRESPONSE._serialized_end=1017
  _KAFKAEXPORTERSSERVICE._serialized_start=1020
  _KAFKAEXPORTERSSERVICE._serialized_end=1643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/installations/v1/installations_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\x1a\x17validate/validate.proto\"K\n\x16GetInstallationRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"r\n\x17GetInstallationResponse\x12W\n\x0cinstallation\x18\x01 \x01(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02R\x0cinstallation\"\x1a\n\x18ListInstallationsRequest\"v\n\x19ListInstallationsResponse\x12Y\n\rinstallations\x18\x01 \x03(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02R\rinstallations\"G\n\x1dGetProjectInstallationRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId:\x02\x18\x01\"R\n\x1eGetProjectInstallationResponse\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId:\x02\x18\x01\"S\n\x1fListInstallationProjectsRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId:\x02\x18\x01\"G\n ListInstallationProjectsResponse\x12\x1f\n\x0bproject_ids\x18\x01 \x03(\tR\nprojectIds:\x02\x18\x01\x32\xfa\x04\n\x14InstallationsService\x12\x86\x01\n\x0fGetInstallation\x12\x38.strmprivacy.api.installations.v1.GetInstallationRequest\x1a\x39.strmprivacy.api.installations.v1.GetInstallationResponse\x12\x8c\x01\n\x11ListInstallations\x12:.strmprivacy.api.installations.v1.ListInstallationsRequest\x1a;.strmprivacy.api.installations.v1.ListInstallationsResponse\x12\xa0\x01\n\x16GetProjectInstallation\x12?.strmprivacy.api.installations.v1.GetProjectInstallationRequest\x1a@.strmprivacy.api.installations.v1.GetProjectInstallationResponse\"\x03\x88\x02\x01\x12\xa6\x01\n\x18ListInstallationProjects\x12\x41.strmprivacy.api.installations.v1.ListInstallationProjectsRequest\x1a\x42.strmprivacy.api.installations.v1.ListInstallationProjectsResponse\"\x03\x88\x02\x01\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.installations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._options = None
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._options = None
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST._options = None
  _GETPROJECTINSTALLATIONREQUEST._serialized_options = b'\030\001'
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._options = None
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONRESPONSE._options = None
  _GETPROJECTINSTALLATIONRESPONSE._serialized_options = b'\030\001'
  _LISTINSTALLATIONPROJECTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLATIONPROJECTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONPROJECTSREQUEST._options = None
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_options = b'\030\001'
  _LISTINSTALLATIONPROJECTSRESPONSE._options = None
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_options = b'\030\001'
  _INSTALLATIONSSERVICE.methods_by_name['GetProjectInstallation']._options = None
  _INSTALLATIONSSERVICE.methods_by_name['GetProjectInstallation']._serialized_options = b'\210\002\001'
  _INSTALLATIONSSERVICE.methods_by_name['ListInstallationProjects']._options = None
  _INSTALLATIONSSERVICE.methods_by_name['ListInstallationProjects']._serialized_options = b'\210\002\001'
  _GETINSTALLATIONREQUEST._serialized_start=203
  _GETINSTALLATIONREQUEST._serialized_end=278
  _GETINSTALLATIONRESPONSE._serialized_start=280
  _GETINSTALLATIONRESPONSE._serialized_end=394
  _LISTINSTALLATIONSREQUEST._serialized_start=396
  _LISTINSTALLATIONSREQUEST._serialized_end=422
  _LISTINSTALLATIONSRESPONSE._serialized_start=424
  _LISTINSTALLATIONSRESPONSE._serialized_end=542
  _GETPROJECTINSTALLATIONREQUEST._serialized_start=544
  _GETPROJECTINSTALLATIONREQUEST._serialized_end=615
  _GETPROJECTINSTALLATIONRESPONSE._serialized_start=617
  _GETPROJECTINSTALLATIONRESPONSE._serialized_end=699
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_start=701
  _LISTINSTALLATIONPROJECTSREQUEST._serialized_end=784
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_start=786
  _LISTINSTALLATIONPROJECTSRESPONSE._serialized_end=857
  _INSTALLATIONSSERVICE._serialized_start=860
  _INSTALLATIONSSERVICE._serialized_end=1494
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.account.v1 import account_v1_pb2 as strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2


class AccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountDetails = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/GetAccountDetails',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsResponse.FromString,
                )
        self.GetLegacyBillingId = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/GetLegacyBillingId',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdResponse.FromString,
                )
        self.CreateAccountHandle = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/CreateAccountHandle',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleResponse.FromString,
                )
        self.InitializeCheckout = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/InitializeCheckout',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutResponse.FromString,
                )
        self.GetCheckoutStatus = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/GetCheckoutStatus',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusResponse.FromString,
                )
        self.InitializeCustomerPortal = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/InitializeCustomerPortal',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalResponse.FromString,
                )
        self.SetCheckoutCancelled = channel.unary_unary(
                '/strmprivacy.api.account.v1.AccountService/SetCheckoutCancelled',
                request_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledResponse.FromString,
                )


class AccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccountDetails(self, request, context):
        """Retrieve information regarding quotas, and the user context
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLegacyBillingId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccountHandle(self, request, context):
        """Claim and create a handle for your user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitializeCheckout(self, request, context):
        """Start a checkout to subscribe to a specific subscription
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCheckoutStatus(self, request, context):
        """Get the Stripe Checkout Status for an ongoing checkout
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitializeCustomerPortal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetCheckoutCancelled(self, request, context):
        """(-- api-linter: core::0134::synonyms=disabled
        aip.dev/not-precedent: We're not updating a Checkout here. --)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountDetails,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsResponse.SerializeToString,
            ),
            'GetLegacyBillingId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLegacyBillingId,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdResponse.SerializeToString,
            ),
            'CreateAccountHandle': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccountHandle,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleResponse.SerializeToString,
            ),
            'InitializeCheckout': grpc.unary_unary_rpc_method_handler(
                    servicer.InitializeCheckout,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutResponse.SerializeToString,
            ),
            'GetCheckoutStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCheckoutStatus,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusResponse.SerializeToString,
            ),
            'InitializeCustomerPortal': grpc.unary_unary_rpc_method_handler(
                    servicer.InitializeCustomerPortal,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalResponse.SerializeToString,
            ),
            'SetCheckoutCancelled': grpc.unary_unary_rpc_method_handler(
                    servicer.SetCheckoutCancelled,
                    request_deserializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.account.v1.AccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccountDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/GetAccountDetails',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetAccountDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLegacyBillingId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/GetLegacyBillingId',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetLegacyBillingIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccountHandle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/CreateAccountHandle',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.CreateAccountHandleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitializeCheckout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/InitializeCheckout',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCheckoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCheckoutStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/GetCheckoutStatus',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.GetCheckoutStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitializeCustomerPortal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/InitializeCustomerPortal',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.InitializeCustomerPortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetCheckoutCancelled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.account.v1.AccountService/SetCheckoutCancelled',
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledRequest.SerializeToString,
            strmprivacy_dot_api_dot_account_dot_v1_dot_account__v1__pb2.SetCheckoutCancelledResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_connectors.v1 import data_connectors_v1_pb2 as strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2


class DataConnectorsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataConnectors = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/ListDataConnectors',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.FromString,
                )
        self.GetDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/GetDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.FromString,
                )
        self.DeleteDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/DeleteDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.FromString,
                )
        self.CreateDataConnector = channel.unary_unary(
                '/strmprivacy.api.data_connectors.v1.DataConnectorsService/CreateDataConnector',
                request_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.FromString,
                )


class DataConnectorsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataConnectors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataConnector(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataConnectorsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataConnectors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataConnectors,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.SerializeToString,
            ),
            'GetDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.SerializeToString,
            ),
            'DeleteDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.SerializeToString,
            ),
            'CreateDataConnector': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataConnector,
                    request_deserializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_connectors.v1.DataConnectorsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataConnectorsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataConnectors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/ListDataConnectors',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.ListDataConnectorsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/GetDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.GetDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/DeleteDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.DeleteDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataConnector(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_connectors.v1.DataConnectorsService/CreateDataConnector',
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__connectors_dot_v1_dot_data__connectors__v1__pb2.CreateDataConnectorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.kafka_clusters.v1 import kafka_clusters_v1_pb2 as strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2


class KafkaClustersServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListKafkaClusters = channel.unary_unary(
                '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/ListKafkaClusters',
                request_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersResponse.FromString,
                )
        self.GetKafkaCluster = channel.unary_unary(
                '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/GetKafkaCluster',
                request_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterResponse.FromString,
                )
        self.DeleteKafkaCluster = channel.unary_unary(
                '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/DeleteKafkaCluster',
                request_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterResponse.FromString,
                )
        self.CreateKafkaCluster = channel.unary_unary(
                '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/CreateKafkaCluster',
                request_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterResponse.FromString,
                )


class KafkaClustersServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListKafkaClusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKafkaCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteKafkaCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateKafkaCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_KafkaClustersServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListKafkaClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKafkaClusters,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersResponse.SerializeToString,
            ),
            'GetKafkaCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKafkaCluster,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterResponse.SerializeToString,
            ),
            'DeleteKafkaCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteKafkaCluster,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterResponse.SerializeToString,
            ),
            'CreateKafkaCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateKafkaCluster,
                    request_deserializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.kafka_clusters.v1.KafkaClustersService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class KafkaClustersService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListKafkaClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/ListKafkaClusters',
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.ListKafkaClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetKafkaCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/GetKafkaCluster',
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.GetKafkaClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteKafkaCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/DeleteKafkaCluster',
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.DeleteKafkaClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateKafkaCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.kafka_clusters.v1.KafkaClustersService/CreateKafkaCluster',
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterRequest.SerializeToString,
            strmprivacy_dot_api_dot_kafka__clusters_dot_v1_dot_kafka__clusters__v1__pb2.CreateKafkaClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
